# crc-pulpcore-client
Fetch, Upload, Organize, and Distribute Software Packages

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 20250821.1
- Generator version: 7.10.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import crc-pulpcore-client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import crc-pulpcore-client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import crc-pulpcore-client
from crc-pulpcore-client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://env-ephemeral-iqasyf.apps.crc-eph.r9lp.p1.openshiftapps.com
# See configuration.py for a list of all supported configuration parameters.
configuration = crc-pulpcore-client.Configuration(
    host = "https://env-ephemeral-iqasyf.apps.crc-eph.r9lp.p1.openshiftapps.com"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

configuration.access_token = os.environ["ACCESS_TOKEN"]

# Configure HTTP basic authorization: basicAuth
configuration = crc-pulpcore-client.Configuration(
    username = os.environ["USERNAME"],
    password = os.environ["PASSWORD"]
)

# Configure API key authorization: cookieAuth
configuration.api_key['cookieAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['cookieAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with crc-pulpcore-client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = crc-pulpcore-client.AccessPoliciesApi(api_client)
    pulp_domain = 'pulp_domain_example' # str | 
    x_task_diagnostics = ['x_task_diagnostics_example'] # List[str] | List of profilers to use on tasks. (optional)
    customized = True # bool | Filter results where customized matches value (optional)
    limit = 56 # int | Number of results to return per page. (optional)
    offset = 56 # int | The initial index from which to return the results. (optional)
    ordering = ['ordering_example'] # List[str] | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `creation_hooks` - Creation hooks * `-creation_hooks` - Creation hooks (descending) * `statements` - Statements * `-statements` - Statements (descending) * `viewset_name` - Viewset name * `-viewset_name` - Viewset name (descending) * `customized` - Customized * `-customized` - Customized (descending) * `queryset_scoping` - Queryset scoping * `-queryset_scoping` - Queryset scoping (descending) * `pk` - Pk * `-pk` - Pk (descending) (optional)
    prn__in = ['prn__in_example'] # List[str] | Multiple values may be separated by commas. (optional)
    pulp_href__in = ['pulp_href__in_example'] # List[str] | Multiple values may be separated by commas. (optional)
    pulp_id__in = ['pulp_id__in_example'] # List[str] | Multiple values may be separated by commas. (optional)
    q = 'q_example' # str | Filter results by using NOT, AND and OR operations on other filters (optional)
    viewset_name = 'viewset_name_example' # str | Filter results where viewset_name matches value (optional)
    viewset_name__contains = 'viewset_name__contains_example' # str | Filter results where viewset_name contains value (optional)
    viewset_name__icontains = 'viewset_name__icontains_example' # str | Filter results where viewset_name contains value (optional)
    viewset_name__iexact = 'viewset_name__iexact_example' # str | Filter results where viewset_name matches value (optional)
    viewset_name__in = ['viewset_name__in_example'] # List[str] | Filter results where viewset_name is in a comma-separated list of values (optional)
    viewset_name__iregex = 'viewset_name__iregex_example' # str | Filter results where viewset_name matches regex value (optional)
    viewset_name__istartswith = 'viewset_name__istartswith_example' # str | Filter results where viewset_name starts with value (optional)
    viewset_name__regex = 'viewset_name__regex_example' # str | Filter results where viewset_name matches regex value (optional)
    viewset_name__startswith = 'viewset_name__startswith_example' # str | Filter results where viewset_name starts with value (optional)
    fields = ['fields_example'] # List[str] | A list of fields to include in the response. (optional)
    exclude_fields = ['exclude_fields_example'] # List[str] | A list of fields to exclude from the response. (optional)

    try:
        # List access policys
        api_response = api_instance.list(pulp_domain, x_task_diagnostics=x_task_diagnostics, customized=customized, limit=limit, offset=offset, ordering=ordering, prn__in=prn__in, pulp_href__in=pulp_href__in, pulp_id__in=pulp_id__in, q=q, viewset_name=viewset_name, viewset_name__contains=viewset_name__contains, viewset_name__icontains=viewset_name__icontains, viewset_name__iexact=viewset_name__iexact, viewset_name__in=viewset_name__in, viewset_name__iregex=viewset_name__iregex, viewset_name__istartswith=viewset_name__istartswith, viewset_name__regex=viewset_name__regex, viewset_name__startswith=viewset_name__startswith, fields=fields, exclude_fields=exclude_fields)
        print("The response of AccessPoliciesApi->list:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccessPoliciesApi->list: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://env-ephemeral-iqasyf.apps.crc-eph.r9lp.p1.openshiftapps.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccessPoliciesApi* | [**list**](docs/AccessPoliciesApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/access_policies/ | List access policys
*AccessPoliciesApi* | [**partial_update**](docs/AccessPoliciesApi.md#partial_update) | **PATCH** {access_policy_href} | Update an access policy
*AccessPoliciesApi* | [**read**](docs/AccessPoliciesApi.md#read) | **GET** {access_policy_href} | Inspect an access policy
*AccessPoliciesApi* | [**reset**](docs/AccessPoliciesApi.md#reset) | **POST** {access_policy_href}reset/ | 
*AccessPoliciesApi* | [**update**](docs/AccessPoliciesApi.md#update) | **PUT** {access_policy_href} | Update an access policy
*ArtifactsApi* | [**create**](docs/ArtifactsApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/artifacts/ | Create an artifact
*ArtifactsApi* | [**delete**](docs/ArtifactsApi.md#delete) | **DELETE** {artifact_href} | Delete an artifact
*ArtifactsApi* | [**list**](docs/ArtifactsApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/artifacts/ | List artifacts
*ArtifactsApi* | [**read**](docs/ArtifactsApi.md#read) | **GET** {artifact_href} | Inspect an artifact
*ContentApi* | [**list**](docs/ContentApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/content/ | List content
*ContentOpenpgpPublickeyApi* | [**create**](docs/ContentOpenpgpPublickeyApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/content/core/openpgp_publickey/ | Create an open pgp public key
*ContentOpenpgpPublickeyApi* | [**list**](docs/ContentOpenpgpPublickeyApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/content/core/openpgp_publickey/ | List open pgp public keys
*ContentOpenpgpPublickeyApi* | [**read**](docs/ContentOpenpgpPublickeyApi.md#read) | **GET** {open_p_g_p_public_key_href} | Inspect an open pgp public key
*ContentOpenpgpPublickeyApi* | [**set_label**](docs/ContentOpenpgpPublickeyApi.md#set_label) | **POST** {open_p_g_p_public_key_href}set_label/ | Set a label
*ContentOpenpgpPublickeyApi* | [**unset_label**](docs/ContentOpenpgpPublickeyApi.md#unset_label) | **POST** {open_p_g_p_public_key_href}unset_label/ | Unset a label
*ContentOpenpgpPublicsubkeyApi* | [**list**](docs/ContentOpenpgpPublicsubkeyApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/content/core/openpgp_publicsubkey/ | List open pgp public subkeys
*ContentOpenpgpPublicsubkeyApi* | [**read**](docs/ContentOpenpgpPublicsubkeyApi.md#read) | **GET** {open_p_g_p_public_subkey_href} | Inspect an open pgp public subkey
*ContentOpenpgpPublicsubkeyApi* | [**set_label**](docs/ContentOpenpgpPublicsubkeyApi.md#set_label) | **POST** {open_p_g_p_public_subkey_href}set_label/ | Set a label
*ContentOpenpgpPublicsubkeyApi* | [**unset_label**](docs/ContentOpenpgpPublicsubkeyApi.md#unset_label) | **POST** {open_p_g_p_public_subkey_href}unset_label/ | Unset a label
*ContentOpenpgpSignatureApi* | [**list**](docs/ContentOpenpgpSignatureApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/content/core/openpgp_signature/ | List open pgp signatures
*ContentOpenpgpSignatureApi* | [**read**](docs/ContentOpenpgpSignatureApi.md#read) | **GET** {open_p_g_p_signature_href} | Inspect an open pgp signature
*ContentOpenpgpSignatureApi* | [**set_label**](docs/ContentOpenpgpSignatureApi.md#set_label) | **POST** {open_p_g_p_signature_href}set_label/ | Set a label
*ContentOpenpgpSignatureApi* | [**unset_label**](docs/ContentOpenpgpSignatureApi.md#unset_label) | **POST** {open_p_g_p_signature_href}unset_label/ | Unset a label
*ContentOpenpgpUserattributeApi* | [**list**](docs/ContentOpenpgpUserattributeApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/content/core/openpgp_userattribute/ | List open pgp user attributes
*ContentOpenpgpUserattributeApi* | [**read**](docs/ContentOpenpgpUserattributeApi.md#read) | **GET** {open_p_g_p_user_attribute_href} | Inspect an open pgp user attribute
*ContentOpenpgpUserattributeApi* | [**set_label**](docs/ContentOpenpgpUserattributeApi.md#set_label) | **POST** {open_p_g_p_user_attribute_href}set_label/ | Set a label
*ContentOpenpgpUserattributeApi* | [**unset_label**](docs/ContentOpenpgpUserattributeApi.md#unset_label) | **POST** {open_p_g_p_user_attribute_href}unset_label/ | Unset a label
*ContentOpenpgpUseridApi* | [**list**](docs/ContentOpenpgpUseridApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/content/core/openpgp_userid/ | List open pgp user ids
*ContentOpenpgpUseridApi* | [**read**](docs/ContentOpenpgpUseridApi.md#read) | **GET** {open_p_g_p_user_i_d_href} | Inspect an open pgp user id
*ContentOpenpgpUseridApi* | [**set_label**](docs/ContentOpenpgpUseridApi.md#set_label) | **POST** {open_p_g_p_user_i_d_href}set_label/ | Set a label
*ContentOpenpgpUseridApi* | [**unset_label**](docs/ContentOpenpgpUseridApi.md#unset_label) | **POST** {open_p_g_p_user_i_d_href}unset_label/ | Unset a label
*ContentguardsApi* | [**list**](docs/ContentguardsApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/contentguards/ | List content guards
*ContentguardsCompositeApi* | [**add_role**](docs/ContentguardsCompositeApi.md#add_role) | **POST** {composite_content_guard_href}add_role/ | Add a role
*ContentguardsCompositeApi* | [**create**](docs/ContentguardsCompositeApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/contentguards/core/composite/ | Create a composite content guard
*ContentguardsCompositeApi* | [**delete**](docs/ContentguardsCompositeApi.md#delete) | **DELETE** {composite_content_guard_href} | Delete a composite content guard
*ContentguardsCompositeApi* | [**list**](docs/ContentguardsCompositeApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/contentguards/core/composite/ | List composite content guards
*ContentguardsCompositeApi* | [**list_roles**](docs/ContentguardsCompositeApi.md#list_roles) | **GET** {composite_content_guard_href}list_roles/ | List roles
*ContentguardsCompositeApi* | [**my_permissions**](docs/ContentguardsCompositeApi.md#my_permissions) | **GET** {composite_content_guard_href}my_permissions/ | List user permissions
*ContentguardsCompositeApi* | [**partial_update**](docs/ContentguardsCompositeApi.md#partial_update) | **PATCH** {composite_content_guard_href} | Update a composite content guard
*ContentguardsCompositeApi* | [**read**](docs/ContentguardsCompositeApi.md#read) | **GET** {composite_content_guard_href} | Inspect a composite content guard
*ContentguardsCompositeApi* | [**remove_role**](docs/ContentguardsCompositeApi.md#remove_role) | **POST** {composite_content_guard_href}remove_role/ | Remove a role
*ContentguardsCompositeApi* | [**update**](docs/ContentguardsCompositeApi.md#update) | **PUT** {composite_content_guard_href} | Update a composite content guard
*ContentguardsContentRedirectApi* | [**add_role**](docs/ContentguardsContentRedirectApi.md#add_role) | **POST** {content_redirect_content_guard_href}add_role/ | Add a role
*ContentguardsContentRedirectApi* | [**create**](docs/ContentguardsContentRedirectApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/contentguards/core/content_redirect/ | Create a content redirect content guard
*ContentguardsContentRedirectApi* | [**delete**](docs/ContentguardsContentRedirectApi.md#delete) | **DELETE** {content_redirect_content_guard_href} | Delete a content redirect content guard
*ContentguardsContentRedirectApi* | [**list**](docs/ContentguardsContentRedirectApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/contentguards/core/content_redirect/ | List content redirect content guards
*ContentguardsContentRedirectApi* | [**list_roles**](docs/ContentguardsContentRedirectApi.md#list_roles) | **GET** {content_redirect_content_guard_href}list_roles/ | List roles
*ContentguardsContentRedirectApi* | [**my_permissions**](docs/ContentguardsContentRedirectApi.md#my_permissions) | **GET** {content_redirect_content_guard_href}my_permissions/ | List user permissions
*ContentguardsContentRedirectApi* | [**partial_update**](docs/ContentguardsContentRedirectApi.md#partial_update) | **PATCH** {content_redirect_content_guard_href} | Update a content redirect content guard
*ContentguardsContentRedirectApi* | [**read**](docs/ContentguardsContentRedirectApi.md#read) | **GET** {content_redirect_content_guard_href} | Inspect a content redirect content guard
*ContentguardsContentRedirectApi* | [**remove_role**](docs/ContentguardsContentRedirectApi.md#remove_role) | **POST** {content_redirect_content_guard_href}remove_role/ | Remove a role
*ContentguardsContentRedirectApi* | [**update**](docs/ContentguardsContentRedirectApi.md#update) | **PUT** {content_redirect_content_guard_href} | Update a content redirect content guard
*ContentguardsHeaderApi* | [**add_role**](docs/ContentguardsHeaderApi.md#add_role) | **POST** {header_content_guard_href}add_role/ | Add a role
*ContentguardsHeaderApi* | [**create**](docs/ContentguardsHeaderApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/contentguards/core/header/ | Create a header content guard
*ContentguardsHeaderApi* | [**delete**](docs/ContentguardsHeaderApi.md#delete) | **DELETE** {header_content_guard_href} | Delete a header content guard
*ContentguardsHeaderApi* | [**list**](docs/ContentguardsHeaderApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/contentguards/core/header/ | List header content guards
*ContentguardsHeaderApi* | [**list_roles**](docs/ContentguardsHeaderApi.md#list_roles) | **GET** {header_content_guard_href}list_roles/ | List roles
*ContentguardsHeaderApi* | [**my_permissions**](docs/ContentguardsHeaderApi.md#my_permissions) | **GET** {header_content_guard_href}my_permissions/ | List user permissions
*ContentguardsHeaderApi* | [**partial_update**](docs/ContentguardsHeaderApi.md#partial_update) | **PATCH** {header_content_guard_href} | Update a header content guard
*ContentguardsHeaderApi* | [**read**](docs/ContentguardsHeaderApi.md#read) | **GET** {header_content_guard_href} | Inspect a header content guard
*ContentguardsHeaderApi* | [**remove_role**](docs/ContentguardsHeaderApi.md#remove_role) | **POST** {header_content_guard_href}remove_role/ | Remove a role
*ContentguardsHeaderApi* | [**update**](docs/ContentguardsHeaderApi.md#update) | **PUT** {header_content_guard_href} | Update a header content guard
*ContentguardsRbacApi* | [**add_role**](docs/ContentguardsRbacApi.md#add_role) | **POST** {r_b_a_c_content_guard_href}add_role/ | Add a role
*ContentguardsRbacApi* | [**create**](docs/ContentguardsRbacApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/contentguards/core/rbac/ | Create a rbac content guard
*ContentguardsRbacApi* | [**delete**](docs/ContentguardsRbacApi.md#delete) | **DELETE** {r_b_a_c_content_guard_href} | Delete a rbac content guard
*ContentguardsRbacApi* | [**list**](docs/ContentguardsRbacApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/contentguards/core/rbac/ | List rbac content guards
*ContentguardsRbacApi* | [**list_roles**](docs/ContentguardsRbacApi.md#list_roles) | **GET** {r_b_a_c_content_guard_href}list_roles/ | List roles
*ContentguardsRbacApi* | [**my_permissions**](docs/ContentguardsRbacApi.md#my_permissions) | **GET** {r_b_a_c_content_guard_href}my_permissions/ | List user permissions
*ContentguardsRbacApi* | [**partial_update**](docs/ContentguardsRbacApi.md#partial_update) | **PATCH** {r_b_a_c_content_guard_href} | Update a rbac content guard
*ContentguardsRbacApi* | [**read**](docs/ContentguardsRbacApi.md#read) | **GET** {r_b_a_c_content_guard_href} | Inspect a rbac content guard
*ContentguardsRbacApi* | [**remove_role**](docs/ContentguardsRbacApi.md#remove_role) | **POST** {r_b_a_c_content_guard_href}remove_role/ | Remove a role
*ContentguardsRbacApi* | [**update**](docs/ContentguardsRbacApi.md#update) | **PUT** {r_b_a_c_content_guard_href} | Update a rbac content guard
*DistributionsApi* | [**list**](docs/DistributionsApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/distributions/ | List distributions
*DistributionsArtifactsApi* | [**list**](docs/DistributionsArtifactsApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/distributions/core/artifacts/ | List artifact distributions
*DistributionsArtifactsApi* | [**read**](docs/DistributionsArtifactsApi.md#read) | **GET** {artifact_distribution_href} | Inspect an artifact distribution
*DistributionsOpenpgpApi* | [**create**](docs/DistributionsOpenpgpApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/distributions/core/openpgp/ | Create an open pgp distribution
*DistributionsOpenpgpApi* | [**delete**](docs/DistributionsOpenpgpApi.md#delete) | **DELETE** {open_p_g_p_distribution_href} | Delete an open pgp distribution
*DistributionsOpenpgpApi* | [**list**](docs/DistributionsOpenpgpApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/distributions/core/openpgp/ | List open pgp distributions
*DistributionsOpenpgpApi* | [**partial_update**](docs/DistributionsOpenpgpApi.md#partial_update) | **PATCH** {open_p_g_p_distribution_href} | Update an open pgp distribution
*DistributionsOpenpgpApi* | [**read**](docs/DistributionsOpenpgpApi.md#read) | **GET** {open_p_g_p_distribution_href} | Inspect an open pgp distribution
*DistributionsOpenpgpApi* | [**set_label**](docs/DistributionsOpenpgpApi.md#set_label) | **POST** {open_p_g_p_distribution_href}set_label/ | Set a label
*DistributionsOpenpgpApi* | [**unset_label**](docs/DistributionsOpenpgpApi.md#unset_label) | **POST** {open_p_g_p_distribution_href}unset_label/ | Unset a label
*DistributionsOpenpgpApi* | [**update**](docs/DistributionsOpenpgpApi.md#update) | **PUT** {open_p_g_p_distribution_href} | Update an open pgp distribution
*DomainsApi* | [**create**](docs/DomainsApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/domains/ | Create a domain
*DomainsApi* | [**delete**](docs/DomainsApi.md#delete) | **DELETE** {domain_href} | Delete a domain
*DomainsApi* | [**list**](docs/DomainsApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/domains/ | List domains
*DomainsApi* | [**migrate**](docs/DomainsApi.md#migrate) | **POST** /api/pulp/{pulp_domain}/api/v3/domains/migrate/ | Migrate storage backend
*DomainsApi* | [**partial_update**](docs/DomainsApi.md#partial_update) | **PATCH** {domain_href} | Update a domain
*DomainsApi* | [**read**](docs/DomainsApi.md#read) | **GET** {domain_href} | Inspect a domain
*DomainsApi* | [**set_label**](docs/DomainsApi.md#set_label) | **POST** {domain_href}set_label/ | Set a label
*DomainsApi* | [**unset_label**](docs/DomainsApi.md#unset_label) | **POST** {domain_href}unset_label/ | Unset a label
*DomainsApi* | [**update**](docs/DomainsApi.md#update) | **PUT** {domain_href} | Update a domain
*ExportersFilesystemApi* | [**create**](docs/ExportersFilesystemApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/exporters/core/filesystem/ | Create a filesystem exporter
*ExportersFilesystemApi* | [**delete**](docs/ExportersFilesystemApi.md#delete) | **DELETE** {filesystem_exporter_href} | Delete a filesystem exporter
*ExportersFilesystemApi* | [**list**](docs/ExportersFilesystemApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/exporters/core/filesystem/ | List filesystem exporters
*ExportersFilesystemApi* | [**partial_update**](docs/ExportersFilesystemApi.md#partial_update) | **PATCH** {filesystem_exporter_href} | Update a filesystem exporter
*ExportersFilesystemApi* | [**read**](docs/ExportersFilesystemApi.md#read) | **GET** {filesystem_exporter_href} | Inspect a filesystem exporter
*ExportersFilesystemApi* | [**update**](docs/ExportersFilesystemApi.md#update) | **PUT** {filesystem_exporter_href} | Update a filesystem exporter
*ExportersFilesystemExportsApi* | [**create**](docs/ExportersFilesystemExportsApi.md#create) | **POST** {filesystem_exporter_href}exports/ | Create a filesystem export
*ExportersFilesystemExportsApi* | [**delete**](docs/ExportersFilesystemExportsApi.md#delete) | **DELETE** {filesystem_filesystem_export_href} | Delete a filesystem export
*ExportersFilesystemExportsApi* | [**list**](docs/ExportersFilesystemExportsApi.md#list) | **GET** {filesystem_exporter_href}exports/ | List filesystem exports
*ExportersFilesystemExportsApi* | [**read**](docs/ExportersFilesystemExportsApi.md#read) | **GET** {filesystem_filesystem_export_href} | Inspect a filesystem export
*ExportersPulpApi* | [**create**](docs/ExportersPulpApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/exporters/core/pulp/ | Create a pulp exporter
*ExportersPulpApi* | [**delete**](docs/ExportersPulpApi.md#delete) | **DELETE** {pulp_exporter_href} | Delete a pulp exporter
*ExportersPulpApi* | [**list**](docs/ExportersPulpApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/exporters/core/pulp/ | List pulp exporters
*ExportersPulpApi* | [**partial_update**](docs/ExportersPulpApi.md#partial_update) | **PATCH** {pulp_exporter_href} | Update a pulp exporter
*ExportersPulpApi* | [**read**](docs/ExportersPulpApi.md#read) | **GET** {pulp_exporter_href} | Inspect a pulp exporter
*ExportersPulpApi* | [**update**](docs/ExportersPulpApi.md#update) | **PUT** {pulp_exporter_href} | Update a pulp exporter
*ExportersPulpExportsApi* | [**create**](docs/ExportersPulpExportsApi.md#create) | **POST** {pulp_exporter_href}exports/ | Create a pulp export
*ExportersPulpExportsApi* | [**delete**](docs/ExportersPulpExportsApi.md#delete) | **DELETE** {pulp_pulp_export_href} | Delete a pulp export
*ExportersPulpExportsApi* | [**list**](docs/ExportersPulpExportsApi.md#list) | **GET** {pulp_exporter_href}exports/ | List pulp exports
*ExportersPulpExportsApi* | [**read**](docs/ExportersPulpExportsApi.md#read) | **GET** {pulp_pulp_export_href} | Inspect a pulp export
*GroupsApi* | [**add_role**](docs/GroupsApi.md#add_role) | **POST** {group_href}add_role/ | Add a role
*GroupsApi* | [**create**](docs/GroupsApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/groups/ | Create a group
*GroupsApi* | [**delete**](docs/GroupsApi.md#delete) | **DELETE** {group_href} | Delete a group
*GroupsApi* | [**list**](docs/GroupsApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/groups/ | List groups
*GroupsApi* | [**list_roles**](docs/GroupsApi.md#list_roles) | **GET** {group_href}list_roles/ | List roles
*GroupsApi* | [**my_permissions**](docs/GroupsApi.md#my_permissions) | **GET** {group_href}my_permissions/ | List user permissions
*GroupsApi* | [**partial_update**](docs/GroupsApi.md#partial_update) | **PATCH** {group_href} | Update a group
*GroupsApi* | [**read**](docs/GroupsApi.md#read) | **GET** {group_href} | Inspect a group
*GroupsApi* | [**remove_role**](docs/GroupsApi.md#remove_role) | **POST** {group_href}remove_role/ | Remove a role
*GroupsApi* | [**update**](docs/GroupsApi.md#update) | **PUT** {group_href} | Update a group
*GroupsRolesApi* | [**create**](docs/GroupsRolesApi.md#create) | **POST** {group_href}roles/ | Create a group role
*GroupsRolesApi* | [**delete**](docs/GroupsRolesApi.md#delete) | **DELETE** {groups_group_role_href} | Delete a group role
*GroupsRolesApi* | [**list**](docs/GroupsRolesApi.md#list) | **GET** {group_href}roles/ | List group roles
*GroupsRolesApi* | [**read**](docs/GroupsRolesApi.md#read) | **GET** {groups_group_role_href} | Inspect a group role
*GroupsUsersApi* | [**create**](docs/GroupsUsersApi.md#create) | **POST** {group_href}users/ | Create an user
*GroupsUsersApi* | [**delete**](docs/GroupsUsersApi.md#delete) | **DELETE** {groups_user_href} | Delete an user
*GroupsUsersApi* | [**list**](docs/GroupsUsersApi.md#list) | **GET** {group_href}users/ | List users
*ImportersPulpApi* | [**create**](docs/ImportersPulpApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/importers/core/pulp/ | Create a pulp importer
*ImportersPulpApi* | [**delete**](docs/ImportersPulpApi.md#delete) | **DELETE** {pulp_importer_href} | Delete a pulp importer
*ImportersPulpApi* | [**list**](docs/ImportersPulpApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/importers/core/pulp/ | List pulp importers
*ImportersPulpApi* | [**partial_update**](docs/ImportersPulpApi.md#partial_update) | **PATCH** {pulp_importer_href} | Update a pulp importer
*ImportersPulpApi* | [**read**](docs/ImportersPulpApi.md#read) | **GET** {pulp_importer_href} | Inspect a pulp importer
*ImportersPulpApi* | [**update**](docs/ImportersPulpApi.md#update) | **PUT** {pulp_importer_href} | Update a pulp importer
*ImportersPulpImportCheckApi* | [**pulp_import_check_post**](docs/ImportersPulpImportCheckApi.md#pulp_import_check_post) | **POST** /api/pulp/{pulp_domain}/api/v3/importers/core/pulp/import-check/ | Validate the parameters to be used for a PulpImport call
*ImportersPulpImportsApi* | [**create**](docs/ImportersPulpImportsApi.md#create) | **POST** {pulp_importer_href}imports/ | Create a pulp import
*ImportersPulpImportsApi* | [**delete**](docs/ImportersPulpImportsApi.md#delete) | **DELETE** {pulp_pulp_import_href} | Delete a pulp import
*ImportersPulpImportsApi* | [**list**](docs/ImportersPulpImportsApi.md#list) | **GET** {pulp_importer_href}imports/ | List pulp imports
*ImportersPulpImportsApi* | [**read**](docs/ImportersPulpImportsApi.md#read) | **GET** {pulp_pulp_import_href} | Inspect a pulp import
*LivezApi* | [**livez_read**](docs/LivezApi.md#livez_read) | **GET** /api/pulp/api/v3/livez/ | Inspect liveness of Pulp&#39;s REST API.
*LoginApi* | [**login**](docs/LoginApi.md#login) | **POST** /api/pulp/{pulp_domain}/api/v3/login/ | 
*LoginApi* | [**login_read**](docs/LoginApi.md#login_read) | **GET** /api/pulp/{pulp_domain}/api/v3/login/ | 
*LoginApi* | [**logout**](docs/LoginApi.md#logout) | **DELETE** /api/pulp/{pulp_domain}/api/v3/login/ | 
*OrphansApi* | [**delete**](docs/OrphansApi.md#delete) | **DELETE** /api/pulp/{pulp_domain}/api/v3/orphans/ | Delete orphans
*OrphansCleanupApi* | [**cleanup**](docs/OrphansCleanupApi.md#cleanup) | **POST** /api/pulp/{pulp_domain}/api/v3/orphans/cleanup/ | 
*PublicationsApi* | [**list**](docs/PublicationsApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/publications/ | List publications
*RemotesApi* | [**list**](docs/RemotesApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/remotes/ | List remotes
*RepairApi* | [**post**](docs/RepairApi.md#post) | **POST** /api/pulp/{pulp_domain}/api/v3/repair/ | Repair Artifact Storage
*RepositoriesApi* | [**list**](docs/RepositoriesApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/repositories/ | List repositories
*RepositoriesOpenpgpKeyringApi* | [**add_role**](docs/RepositoriesOpenpgpKeyringApi.md#add_role) | **POST** {open_p_g_p_keyring_href}add_role/ | Add a role
*RepositoriesOpenpgpKeyringApi* | [**create**](docs/RepositoriesOpenpgpKeyringApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/repositories/core/openpgp_keyring/ | Create an open pgp keyring
*RepositoriesOpenpgpKeyringApi* | [**delete**](docs/RepositoriesOpenpgpKeyringApi.md#delete) | **DELETE** {open_p_g_p_keyring_href} | Delete an open pgp keyring
*RepositoriesOpenpgpKeyringApi* | [**list**](docs/RepositoriesOpenpgpKeyringApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/repositories/core/openpgp_keyring/ | List open pgp keyrings
*RepositoriesOpenpgpKeyringApi* | [**list_roles**](docs/RepositoriesOpenpgpKeyringApi.md#list_roles) | **GET** {open_p_g_p_keyring_href}list_roles/ | List roles
*RepositoriesOpenpgpKeyringApi* | [**modify**](docs/RepositoriesOpenpgpKeyringApi.md#modify) | **POST** {open_p_g_p_keyring_href}modify/ | Modify Repository Content
*RepositoriesOpenpgpKeyringApi* | [**my_permissions**](docs/RepositoriesOpenpgpKeyringApi.md#my_permissions) | **GET** {open_p_g_p_keyring_href}my_permissions/ | List user permissions
*RepositoriesOpenpgpKeyringApi* | [**partial_update**](docs/RepositoriesOpenpgpKeyringApi.md#partial_update) | **PATCH** {open_p_g_p_keyring_href} | Update an open pgp keyring
*RepositoriesOpenpgpKeyringApi* | [**read**](docs/RepositoriesOpenpgpKeyringApi.md#read) | **GET** {open_p_g_p_keyring_href} | Inspect an open pgp keyring
*RepositoriesOpenpgpKeyringApi* | [**remove_role**](docs/RepositoriesOpenpgpKeyringApi.md#remove_role) | **POST** {open_p_g_p_keyring_href}remove_role/ | Remove a role
*RepositoriesOpenpgpKeyringApi* | [**set_label**](docs/RepositoriesOpenpgpKeyringApi.md#set_label) | **POST** {open_p_g_p_keyring_href}set_label/ | Set a label
*RepositoriesOpenpgpKeyringApi* | [**unset_label**](docs/RepositoriesOpenpgpKeyringApi.md#unset_label) | **POST** {open_p_g_p_keyring_href}unset_label/ | Unset a label
*RepositoriesOpenpgpKeyringApi* | [**update**](docs/RepositoriesOpenpgpKeyringApi.md#update) | **PUT** {open_p_g_p_keyring_href} | Update an open pgp keyring
*RepositoriesReclaimSpaceApi* | [**reclaim**](docs/RepositoriesReclaimSpaceApi.md#reclaim) | **POST** /api/pulp/{pulp_domain}/api/v3/repositories/reclaim_space/ | 
*RepositoryVersionsApi* | [**list**](docs/RepositoryVersionsApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/repository_versions/ | List repository versions
*RolesApi* | [**create**](docs/RolesApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/roles/ | Create a role
*RolesApi* | [**delete**](docs/RolesApi.md#delete) | **DELETE** {role_href} | Delete a role
*RolesApi* | [**list**](docs/RolesApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/roles/ | List roles
*RolesApi* | [**partial_update**](docs/RolesApi.md#partial_update) | **PATCH** {role_href} | Update a role
*RolesApi* | [**read**](docs/RolesApi.md#read) | **GET** {role_href} | Inspect a role
*RolesApi* | [**update**](docs/RolesApi.md#update) | **PUT** {role_href} | Update a role
*SigningServicesApi* | [**list**](docs/SigningServicesApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/signing-services/ | List signing services
*SigningServicesApi* | [**read**](docs/SigningServicesApi.md#read) | **GET** {signing_service_href} | Inspect a signing service
*StatusApi* | [**status_read**](docs/StatusApi.md#status_read) | **GET** /api/pulp/api/v3/status/ | Inspect status of Pulp
*TaskGroupsApi* | [**list**](docs/TaskGroupsApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/task-groups/ | List task groups
*TaskGroupsApi* | [**read**](docs/TaskGroupsApi.md#read) | **GET** {task_group_href} | Inspect a task group
*TaskGroupsApi* | [**task_groups_cancel**](docs/TaskGroupsApi.md#task_groups_cancel) | **PATCH** {task_group_href} | Cancel a task group
*TaskSchedulesApi* | [**add_role**](docs/TaskSchedulesApi.md#add_role) | **POST** {task_schedule_href}add_role/ | Add a role
*TaskSchedulesApi* | [**list**](docs/TaskSchedulesApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/task-schedules/ | List task schedules
*TaskSchedulesApi* | [**list_roles**](docs/TaskSchedulesApi.md#list_roles) | **GET** {task_schedule_href}list_roles/ | List roles
*TaskSchedulesApi* | [**my_permissions**](docs/TaskSchedulesApi.md#my_permissions) | **GET** {task_schedule_href}my_permissions/ | List user permissions
*TaskSchedulesApi* | [**read**](docs/TaskSchedulesApi.md#read) | **GET** {task_schedule_href} | Inspect a task schedule
*TaskSchedulesApi* | [**remove_role**](docs/TaskSchedulesApi.md#remove_role) | **POST** {task_schedule_href}remove_role/ | Remove a role
*TasksApi* | [**add_role**](docs/TasksApi.md#add_role) | **POST** {task_href}add_role/ | Add a role
*TasksApi* | [**delete**](docs/TasksApi.md#delete) | **DELETE** {task_href} | Delete a task
*TasksApi* | [**list**](docs/TasksApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/tasks/ | List tasks
*TasksApi* | [**list_roles**](docs/TasksApi.md#list_roles) | **GET** {task_href}list_roles/ | List roles
*TasksApi* | [**my_permissions**](docs/TasksApi.md#my_permissions) | **GET** {task_href}my_permissions/ | List user permissions
*TasksApi* | [**profile_artifacts**](docs/TasksApi.md#profile_artifacts) | **GET** {task_href}profile_artifacts/ | Fetch downloadable links for profile artifacts
*TasksApi* | [**purge**](docs/TasksApi.md#purge) | **POST** /api/pulp/{pulp_domain}/api/v3/tasks/purge/ | Purge Completed Tasks
*TasksApi* | [**read**](docs/TasksApi.md#read) | **GET** {task_href} | Inspect a task
*TasksApi* | [**remove_role**](docs/TasksApi.md#remove_role) | **POST** {task_href}remove_role/ | Remove a role
*TasksApi* | [**tasks_cancel**](docs/TasksApi.md#tasks_cancel) | **PATCH** {task_href} | Cancel a task
*UploadsApi* | [**add_role**](docs/UploadsApi.md#add_role) | **POST** {upload_href}add_role/ | Add a role
*UploadsApi* | [**commit**](docs/UploadsApi.md#commit) | **POST** {upload_href}commit/ | Finish an Upload
*UploadsApi* | [**create**](docs/UploadsApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/uploads/ | Create an upload
*UploadsApi* | [**delete**](docs/UploadsApi.md#delete) | **DELETE** {upload_href} | Delete an upload
*UploadsApi* | [**list**](docs/UploadsApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/uploads/ | List uploads
*UploadsApi* | [**list_roles**](docs/UploadsApi.md#list_roles) | **GET** {upload_href}list_roles/ | List roles
*UploadsApi* | [**my_permissions**](docs/UploadsApi.md#my_permissions) | **GET** {upload_href}my_permissions/ | List user permissions
*UploadsApi* | [**read**](docs/UploadsApi.md#read) | **GET** {upload_href} | Inspect an upload
*UploadsApi* | [**remove_role**](docs/UploadsApi.md#remove_role) | **POST** {upload_href}remove_role/ | Remove a role
*UploadsApi* | [**update**](docs/UploadsApi.md#update) | **PUT** {upload_href} | Upload a file chunk
*UpstreamPulpsApi* | [**add_role**](docs/UpstreamPulpsApi.md#add_role) | **POST** {upstream_pulp_href}add_role/ | Add a role
*UpstreamPulpsApi* | [**create**](docs/UpstreamPulpsApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/upstream-pulps/ | Create an upstream pulp
*UpstreamPulpsApi* | [**delete**](docs/UpstreamPulpsApi.md#delete) | **DELETE** {upstream_pulp_href} | Delete an upstream pulp
*UpstreamPulpsApi* | [**list**](docs/UpstreamPulpsApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/upstream-pulps/ | List upstream pulps
*UpstreamPulpsApi* | [**list_roles**](docs/UpstreamPulpsApi.md#list_roles) | **GET** {upstream_pulp_href}list_roles/ | List roles
*UpstreamPulpsApi* | [**my_permissions**](docs/UpstreamPulpsApi.md#my_permissions) | **GET** {upstream_pulp_href}my_permissions/ | List user permissions
*UpstreamPulpsApi* | [**partial_update**](docs/UpstreamPulpsApi.md#partial_update) | **PATCH** {upstream_pulp_href} | Update an upstream pulp
*UpstreamPulpsApi* | [**read**](docs/UpstreamPulpsApi.md#read) | **GET** {upstream_pulp_href} | Inspect an upstream pulp
*UpstreamPulpsApi* | [**remove_role**](docs/UpstreamPulpsApi.md#remove_role) | **POST** {upstream_pulp_href}remove_role/ | Remove a role
*UpstreamPulpsApi* | [**replicate**](docs/UpstreamPulpsApi.md#replicate) | **POST** {upstream_pulp_href}replicate/ | Replicate
*UpstreamPulpsApi* | [**update**](docs/UpstreamPulpsApi.md#update) | **PUT** {upstream_pulp_href} | Update an upstream pulp
*UsersApi* | [**create**](docs/UsersApi.md#create) | **POST** /api/pulp/{pulp_domain}/api/v3/users/ | Create an user
*UsersApi* | [**delete**](docs/UsersApi.md#delete) | **DELETE** {auth_user_href} | Delete an user
*UsersApi* | [**list**](docs/UsersApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/users/ | List users
*UsersApi* | [**partial_update**](docs/UsersApi.md#partial_update) | **PATCH** {auth_user_href} | Update an user
*UsersApi* | [**read**](docs/UsersApi.md#read) | **GET** {auth_user_href} | Inspect an user
*UsersApi* | [**update**](docs/UsersApi.md#update) | **PUT** {auth_user_href} | Update an user
*UsersRolesApi* | [**create**](docs/UsersRolesApi.md#create) | **POST** {auth_user_href}roles/ | Create an user role
*UsersRolesApi* | [**delete**](docs/UsersRolesApi.md#delete) | **DELETE** {auth_users_user_role_href} | Delete an user role
*UsersRolesApi* | [**list**](docs/UsersRolesApi.md#list) | **GET** {auth_user_href}roles/ | List user roles
*UsersRolesApi* | [**read**](docs/UsersRolesApi.md#read) | **GET** {auth_users_user_role_href} | Inspect an user role
*WorkersApi* | [**list**](docs/WorkersApi.md#list) | **GET** /api/pulp/{pulp_domain}/api/v3/workers/ | List workers
*WorkersApi* | [**read**](docs/WorkersApi.md#read) | **GET** {worker_href} | Inspect a worker


## Documentation For Models

 - [AccessPolicy](docs/AccessPolicy.md)
 - [AccessPolicyResponse](docs/AccessPolicyResponse.md)
 - [ApiAppStatusResponse](docs/ApiAppStatusResponse.md)
 - [ArtifactDistributionResponse](docs/ArtifactDistributionResponse.md)
 - [ArtifactResponse](docs/ArtifactResponse.md)
 - [AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [CompositeContentGuard](docs/CompositeContentGuard.md)
 - [CompositeContentGuardResponse](docs/CompositeContentGuardResponse.md)
 - [ContentAppStatusResponse](docs/ContentAppStatusResponse.md)
 - [ContentGuardResponse](docs/ContentGuardResponse.md)
 - [ContentRedirectContentGuard](docs/ContentRedirectContentGuard.md)
 - [ContentRedirectContentGuardResponse](docs/ContentRedirectContentGuardResponse.md)
 - [ContentSettingsResponse](docs/ContentSettingsResponse.md)
 - [ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [DatabaseConnectionResponse](docs/DatabaseConnectionResponse.md)
 - [DistributionResponse](docs/DistributionResponse.md)
 - [Domain](docs/Domain.md)
 - [DomainBackendMigrator](docs/DomainBackendMigrator.md)
 - [DomainResponse](docs/DomainResponse.md)
 - [EvaluationResponse](docs/EvaluationResponse.md)
 - [FilesystemExport](docs/FilesystemExport.md)
 - [FilesystemExportResponse](docs/FilesystemExportResponse.md)
 - [FilesystemExporter](docs/FilesystemExporter.md)
 - [FilesystemExporterResponse](docs/FilesystemExporterResponse.md)
 - [GenericRemoteResponse](docs/GenericRemoteResponse.md)
 - [GenericRemoteResponseHiddenFieldsInner](docs/GenericRemoteResponseHiddenFieldsInner.md)
 - [GenericRemoteResponsePolicyEnum](docs/GenericRemoteResponsePolicyEnum.md)
 - [Group](docs/Group.md)
 - [GroupProgressReportResponse](docs/GroupProgressReportResponse.md)
 - [GroupResponse](docs/GroupResponse.md)
 - [GroupRole](docs/GroupRole.md)
 - [GroupRoleResponse](docs/GroupRoleResponse.md)
 - [GroupUser](docs/GroupUser.md)
 - [GroupUserResponse](docs/GroupUserResponse.md)
 - [HeaderContentGuard](docs/HeaderContentGuard.md)
 - [HeaderContentGuardResponse](docs/HeaderContentGuardResponse.md)
 - [ImportResponse](docs/ImportResponse.md)
 - [LoginResponse](docs/LoginResponse.md)
 - [MethodEnum](docs/MethodEnum.md)
 - [MinimalTaskResponse](docs/MinimalTaskResponse.md)
 - [MultipleArtifactContentResponse](docs/MultipleArtifactContentResponse.md)
 - [MyPermissionsResponse](docs/MyPermissionsResponse.md)
 - [NestedOpenPGPPublicSubkey](docs/NestedOpenPGPPublicSubkey.md)
 - [NestedOpenPGPPublicSubkeyResponse](docs/NestedOpenPGPPublicSubkeyResponse.md)
 - [NestedOpenPGPSignature](docs/NestedOpenPGPSignature.md)
 - [NestedOpenPGPSignatureResponse](docs/NestedOpenPGPSignatureResponse.md)
 - [NestedOpenPGPUserAttribute](docs/NestedOpenPGPUserAttribute.md)
 - [NestedOpenPGPUserAttributeResponse](docs/NestedOpenPGPUserAttributeResponse.md)
 - [NestedOpenPGPUserID](docs/NestedOpenPGPUserID.md)
 - [NestedOpenPGPUserIDResponse](docs/NestedOpenPGPUserIDResponse.md)
 - [NestedRole](docs/NestedRole.md)
 - [NestedRoleResponse](docs/NestedRoleResponse.md)
 - [ObjectRolesResponse](docs/ObjectRolesResponse.md)
 - [OpenPGPDistribution](docs/OpenPGPDistribution.md)
 - [OpenPGPDistributionResponse](docs/OpenPGPDistributionResponse.md)
 - [OpenPGPKeyring](docs/OpenPGPKeyring.md)
 - [OpenPGPKeyringResponse](docs/OpenPGPKeyringResponse.md)
 - [OpenPGPPublicKeyResponse](docs/OpenPGPPublicKeyResponse.md)
 - [OpenPGPPublicSubkeyResponse](docs/OpenPGPPublicSubkeyResponse.md)
 - [OpenPGPSignatureResponse](docs/OpenPGPSignatureResponse.md)
 - [OpenPGPUserAttributeResponse](docs/OpenPGPUserAttributeResponse.md)
 - [OpenPGPUserIDResponse](docs/OpenPGPUserIDResponse.md)
 - [OrphansCleanup](docs/OrphansCleanup.md)
 - [PaginatedAccessPolicyResponseList](docs/PaginatedAccessPolicyResponseList.md)
 - [PaginatedArtifactDistributionResponseList](docs/PaginatedArtifactDistributionResponseList.md)
 - [PaginatedArtifactResponseList](docs/PaginatedArtifactResponseList.md)
 - [PaginatedCompositeContentGuardResponseList](docs/PaginatedCompositeContentGuardResponseList.md)
 - [PaginatedContentGuardResponseList](docs/PaginatedContentGuardResponseList.md)
 - [PaginatedContentRedirectContentGuardResponseList](docs/PaginatedContentRedirectContentGuardResponseList.md)
 - [PaginatedDistributionResponseList](docs/PaginatedDistributionResponseList.md)
 - [PaginatedDomainResponseList](docs/PaginatedDomainResponseList.md)
 - [PaginatedFilesystemExportResponseList](docs/PaginatedFilesystemExportResponseList.md)
 - [PaginatedFilesystemExporterResponseList](docs/PaginatedFilesystemExporterResponseList.md)
 - [PaginatedGenericRemoteResponseList](docs/PaginatedGenericRemoteResponseList.md)
 - [PaginatedGroupResponseList](docs/PaginatedGroupResponseList.md)
 - [PaginatedGroupRoleResponseList](docs/PaginatedGroupRoleResponseList.md)
 - [PaginatedGroupUserResponseList](docs/PaginatedGroupUserResponseList.md)
 - [PaginatedHeaderContentGuardResponseList](docs/PaginatedHeaderContentGuardResponseList.md)
 - [PaginatedImportResponseList](docs/PaginatedImportResponseList.md)
 - [PaginatedMultipleArtifactContentResponseList](docs/PaginatedMultipleArtifactContentResponseList.md)
 - [PaginatedOpenPGPDistributionResponseList](docs/PaginatedOpenPGPDistributionResponseList.md)
 - [PaginatedOpenPGPKeyringResponseList](docs/PaginatedOpenPGPKeyringResponseList.md)
 - [PaginatedOpenPGPPublicKeyResponseList](docs/PaginatedOpenPGPPublicKeyResponseList.md)
 - [PaginatedOpenPGPPublicSubkeyResponseList](docs/PaginatedOpenPGPPublicSubkeyResponseList.md)
 - [PaginatedOpenPGPSignatureResponseList](docs/PaginatedOpenPGPSignatureResponseList.md)
 - [PaginatedOpenPGPUserAttributeResponseList](docs/PaginatedOpenPGPUserAttributeResponseList.md)
 - [PaginatedOpenPGPUserIDResponseList](docs/PaginatedOpenPGPUserIDResponseList.md)
 - [PaginatedPublicationResponseList](docs/PaginatedPublicationResponseList.md)
 - [PaginatedPulpExportResponseList](docs/PaginatedPulpExportResponseList.md)
 - [PaginatedPulpExporterResponseList](docs/PaginatedPulpExporterResponseList.md)
 - [PaginatedPulpImporterResponseList](docs/PaginatedPulpImporterResponseList.md)
 - [PaginatedRBACContentGuardResponseList](docs/PaginatedRBACContentGuardResponseList.md)
 - [PaginatedRepositoryResponseList](docs/PaginatedRepositoryResponseList.md)
 - [PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PaginatedRoleResponseList](docs/PaginatedRoleResponseList.md)
 - [PaginatedSigningServiceResponseList](docs/PaginatedSigningServiceResponseList.md)
 - [PaginatedTaskGroupResponseList](docs/PaginatedTaskGroupResponseList.md)
 - [PaginatedTaskResponseList](docs/PaginatedTaskResponseList.md)
 - [PaginatedTaskScheduleResponseList](docs/PaginatedTaskScheduleResponseList.md)
 - [PaginatedUploadResponseList](docs/PaginatedUploadResponseList.md)
 - [PaginatedUpstreamPulpResponseList](docs/PaginatedUpstreamPulpResponseList.md)
 - [PaginatedUserResponseList](docs/PaginatedUserResponseList.md)
 - [PaginatedUserRoleResponseList](docs/PaginatedUserRoleResponseList.md)
 - [PaginatedWorkerResponseList](docs/PaginatedWorkerResponseList.md)
 - [PatchedAccessPolicy](docs/PatchedAccessPolicy.md)
 - [PatchedCompositeContentGuard](docs/PatchedCompositeContentGuard.md)
 - [PatchedContentRedirectContentGuard](docs/PatchedContentRedirectContentGuard.md)
 - [PatchedDomain](docs/PatchedDomain.md)
 - [PatchedFilesystemExporter](docs/PatchedFilesystemExporter.md)
 - [PatchedGroup](docs/PatchedGroup.md)
 - [PatchedHeaderContentGuard](docs/PatchedHeaderContentGuard.md)
 - [PatchedOpenPGPDistribution](docs/PatchedOpenPGPDistribution.md)
 - [PatchedOpenPGPKeyring](docs/PatchedOpenPGPKeyring.md)
 - [PatchedPulpExporter](docs/PatchedPulpExporter.md)
 - [PatchedPulpImporter](docs/PatchedPulpImporter.md)
 - [PatchedRBACContentGuard](docs/PatchedRBACContentGuard.md)
 - [PatchedRole](docs/PatchedRole.md)
 - [PatchedTaskCancel](docs/PatchedTaskCancel.md)
 - [PatchedUpstreamPulp](docs/PatchedUpstreamPulp.md)
 - [PatchedUser](docs/PatchedUser.md)
 - [Policy357Enum](docs/Policy357Enum.md)
 - [ProfileArtifactResponse](docs/ProfileArtifactResponse.md)
 - [ProgressReportResponse](docs/ProgressReportResponse.md)
 - [PublicationResponse](docs/PublicationResponse.md)
 - [PulpExport](docs/PulpExport.md)
 - [PulpExportResponse](docs/PulpExportResponse.md)
 - [PulpExporter](docs/PulpExporter.md)
 - [PulpExporterResponse](docs/PulpExporterResponse.md)
 - [PulpImport](docs/PulpImport.md)
 - [PulpImportCheck](docs/PulpImportCheck.md)
 - [PulpImportCheckResponse](docs/PulpImportCheckResponse.md)
 - [PulpImporter](docs/PulpImporter.md)
 - [PulpImporterResponse](docs/PulpImporterResponse.md)
 - [Purge](docs/Purge.md)
 - [RBACContentGuard](docs/RBACContentGuard.md)
 - [RBACContentGuardResponse](docs/RBACContentGuardResponse.md)
 - [ReclaimSpace](docs/ReclaimSpace.md)
 - [RedisConnectionResponse](docs/RedisConnectionResponse.md)
 - [Repair](docs/Repair.md)
 - [RepositoryAddRemoveContent](docs/RepositoryAddRemoveContent.md)
 - [RepositoryResponse](docs/RepositoryResponse.md)
 - [RepositoryVersionResponse](docs/RepositoryVersionResponse.md)
 - [Role](docs/Role.md)
 - [RoleResponse](docs/RoleResponse.md)
 - [SetLabel](docs/SetLabel.md)
 - [SetLabelResponse](docs/SetLabelResponse.md)
 - [SigningServiceResponse](docs/SigningServiceResponse.md)
 - [StatesEnum](docs/StatesEnum.md)
 - [StatusResponse](docs/StatusResponse.md)
 - [StorageClassEnum](docs/StorageClassEnum.md)
 - [StorageResponse](docs/StorageResponse.md)
 - [TaskGroupOperationResponse](docs/TaskGroupOperationResponse.md)
 - [TaskGroupResponse](docs/TaskGroupResponse.md)
 - [TaskResponse](docs/TaskResponse.md)
 - [TaskScheduleResponse](docs/TaskScheduleResponse.md)
 - [UnsetLabel](docs/UnsetLabel.md)
 - [UnsetLabelResponse](docs/UnsetLabelResponse.md)
 - [Upload](docs/Upload.md)
 - [UploadChunkResponse](docs/UploadChunkResponse.md)
 - [UploadCommit](docs/UploadCommit.md)
 - [UploadDetailResponse](docs/UploadDetailResponse.md)
 - [UploadResponse](docs/UploadResponse.md)
 - [UpstreamPulp](docs/UpstreamPulp.md)
 - [UpstreamPulpResponse](docs/UpstreamPulpResponse.md)
 - [User](docs/User.md)
 - [UserGroup](docs/UserGroup.md)
 - [UserGroupResponse](docs/UserGroupResponse.md)
 - [UserResponse](docs/UserResponse.md)
 - [UserRole](docs/UserRole.md)
 - [UserRoleResponse](docs/UserRoleResponse.md)
 - [VersionResponse](docs/VersionResponse.md)
 - [WorkerResponse](docs/WorkerResponse.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="basicAuth"></a>
### basicAuth

- **Type**: HTTP basic authentication

<a id="cookieAuth"></a>
### cookieAuth

- **Type**: API key
- **API key parameter name**: sessionid
- **Location**: 

<a id="json_header_remote_authentication"></a>
### json_header_remote_authentication

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **api.console**: grant_access_to_pulp


## Author

pulp-list@redhat.com


